==> django-admin-soft-dashboard-1.0.21.tar.gz: django-admin-soft-dashboard-1.0.21/README.md <==
# [Django Soft Dashboard](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html)

Modern template for **[Django Admin](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html)**, Auth Pages (registration included) crafted on top of **Soft Dashboard**, an open-source **Bootstrap** design.

- [Django Admin Soft](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html) - **Documentation** & Support Links
- [Django Soft Dashboard](https://app-generator.dev/product/soft-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Soft UI Dashboard](https://app-generator.dev/docs/templates/bootstrap/soft-ui-dashboard.html)** (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Django Soft Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap 5 Design.](https://github.com/user-attachments/assets/9d2f1079-965d-40e1-8e14-c8b26b6609fc)

<br />

## [Soft Dashboard PRO Version](https://app-generator.dev/product/soft-ui-dashboard-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-soft-dash-pro.onrender.com/).

- **Simple, Easy-to-Extend** Codebase
- **Soft UI Dashboard** Design - PRO Version
- Bootstrap 5 CSS
- **OAuth** - Github
- **Extended User Profile**
- **API** via DRF 
- **Charts** via ApexJS 
- **Celery** (async tasks)
- **Deployment-Ready** for Render 

![Django Soft Dashboard PRO - Premium starter powered by Django and Bootstrap 5 - actively supported provided by App-Generator.](https://github.com/user-attachments/assets/e615cd04-2340-4dd1-9c38-19b9761fc1e9)

<br />

---
**[Django Soft Dashboard](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**

==> django-admin-soft-dashboard-1.0.23.tar.gz: django-admin-soft-dashboard-1.0.23/README.md <==
# [Django Soft Dashboard](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html)

Modern template for **[Django Admin](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html)**, Auth Pages (registration included) crafted on top of **Soft Dashboard**, an open-source **Bootstrap** design.

- [Django Admin Soft](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html) - **Documentation** & Support Links
- [Django Soft Dashboard](https://app-generator.dev/product/soft-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Soft UI Dashboard](https://app-generator.dev/docs/templates/bootstrap/soft-ui-dashboard.html)** (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Django Soft Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap 5 Design.](https://github.com/user-attachments/assets/8bb25ecd-ced5-425f-956f-e01c3d8a928c)

<br />

## [Soft Dashboard PRO Version](https://app-generator.dev/product/soft-ui-dashboard-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-soft-dash-pro.onrender.com/).

- **Simple, Easy-to-Extend** Codebase
- **Soft UI Dashboard** Design - PRO Version
- Bootstrap 5 CSS
- **OAuth** - Github
- **Extended User Profile**
- **API** via DRF 
- **Charts** via ApexJS 
- **Celery** (async tasks)
- **Deployment-Ready** for Render 

![Django Soft Dashboard PRO - Premium starter powered by Django and Bootstrap 5 - actively supported provided by App-Generator.](https://github.com/user-attachments/assets/36cc976e-1e3f-444c-a951-344ad81206a1)

<br />

---
**[Django Soft Dashboard](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**
